  /********************************************************************************
*	MasterAugust2016.do                                                       	*
*																			  	*
*	This file:																	*
*		Starts from the sectoral elasticities estimated in SAS					*
*		Merges with the calibrated parameters entering the aggregation formula  *
*		Computes the summary statistics reported in Tables 1-3 of the paper		*
*		Computes the aggregate trade elasticities consistent with these data	*
*		Studies the sources of the cross-country dispersion in those elasticities
*																				*
*	Input:																		*
*		sigma_$base.txt: the estimated sectoral elasticities					*
*		weights_M.txt: the calibrated sectoral parameters						*
*		coverage.txt: the database containing statistics on the data coverage	*
*																				*
*	Output:																		*
*		Various tables and graphs, saved in $tablepath and $graphpath			*
*																				*
********************************************************************************/

**** Define working paths
global datapath W:\TradeImbalance_JI\Results\CTU9195_9504_v
global graphpath W:\TradeImbalance_JI\Results\Paper\Graphs_v
global tablepath W:\TradeImbalance_JI\Results\Paper\Tables_v
* datapath: where the .txt files are saved
* graphpath and tablepath: where the output is saved


set scheme s1color
set more off
sysdir set PLUS "`c(pwd)'"

* Import sectoral elasticities
cd $datapath
clear
insheet using sigma_v9195.txt
keep isic3 sigma varsigma j
g epsilon=1-sigma
label var sigma "Estimated sectoral elasticity of substitution"
label var epsilon "Estimated trade elasticity"
label var varsigma "Estimated variance of the elasticity"
sort j isic
save temp, replace

* Import calibrated parameters and merge with sectoral elasticities
clear 
insheet using weights_M.txt
keep j iso3 isic w_kjj_y alpha_kj_y
label var w_kjj_y "Share of domestic goods in sectoral consumption (UNIDO)"
label var alpha_kj_y "Share of sector in overall consumption (UNIDO)"
sort j isic
merge j isic using temp
tab _merge
drop _merge
keep if w_kjj_y!=. & sigma!=.
save base_import, replace

* Add names of countries
use base_import, clear
g pays="Australia" if iso3=="AUS"
replace pays="Austria" if iso3=="AUT"
replace pays="Canada" if iso3=="CAN"
replace pays="Chile" if iso3=="CHL"
replace pays="China" if iso3=="CHN"
replace pays="Cyprus" if iso3=="CYP"
replace pays="Germany" if iso3=="DEU"
replace pays="Spain" if iso3=="ESP"
replace pays="Finland" if iso3=="FIN"
replace pays="France" if iso3=="FRA"
replace pays="United Kingdom" if iso3=="GBR"
replace pays="Greece" if iso3=="GRC"
replace pays="Guatemala" if iso3=="GTM"
replace pays="Hong Kong" if iso3=="HKG"
replace pays="Hungary" if iso3=="HUN"
replace pays="Indonesia" if iso3=="IDN"
replace pays="India" if iso3=="IND"
replace pays="Italy" if iso3=="ITA"
replace pays="Japan" if iso3=="JPN"
replace pays="Korea" if iso3=="KOR"
replace pays="Malaysia" if iso3=="MYS"
replace pays="Norway" if iso3=="NOR"
replace pays="Portugal" if iso3=="PRT"
replace pays="Slovakia" if iso3=="SVK"
replace pays="Sweden" if iso3=="SWE"
replace pays="Turkey" if iso3=="TUR"
replace pays="Taiwan" if iso3=="TWN"
replace pays="United States" if iso3=="USA"
save base_import, replace

* Summary statistics on coverage (Table 1)
use base_import, clear
sort j iso3 pays
collapse (count) nb_sect=sigma, by(j iso3 pays)
keep j iso3 pays nb_sect
sort j
save temp, replace
clear
insheet using coverage.txt
g coverage= v_u9195/ v_init
keep if coverage!=.
keep coverage j
sort j
merge j using temp
keep if _merge==3
drop _merge
sort pays
keep pays nb_sect coverage
order pays nb_sect coverage
br 
export excel using "$tablepath\Table1_MasterAugust2016.xls", firstrow(variables) replace

* Summary statistics on estimated sigmas, by country (Table 2)
use base_import, clear
tabulate isic3, g(sect_)
tabulate iso3, g(country_)
reg epsilon sect_*
reg epsilon country_*
reg epsilon sect_* country_*

g _=alpha_kj_y*w_kjj_y
bys iso3: egen lambda_ag=sum(_)
g dif_lambda=w_kjj_y-lambda_ag

pwcorr epsilon w_kjj_y alpha_kj_y dif_lambda, sig
scatter epsilon w_kjj_y
scatter epsilon w_kjj_y if epsilon>-29
scatter epsilon dif_lambda
scatter epsilon dif_lambda if epsilon>-29

scatter epsilon alpha_kj_y
scatter epsilon alpha_kj_y if epsilon>-29

sort pays
collapse (count) Count=epsilon (mean) Mean=epsilon (median) Median=epsilon (min) Min=epsilon (max) Max=epsilon, by(pays)
br
export excel using "$tablepath\Table2_MasterAugust2016.xls", firstrow(variables) replace

* Summary statistics on estimated elasticities, by sector (Table 3)
use base_import, clear
sort isic
collapse (count) Count=epsilon (mean) Mean=epsilon (median) Median=epsilon (min) Min=epsilon (max) Max=epsilon, by(isic)
br
export excel using "$tablepath\Table3_MasterAugust2016.xls", firstrow(variables) replace

use base_import, clear
sort isic epsilon
bys isic: egen min=min(epsilon)
bys isic: egen max=max(epsilon)
br epsilon isic pays if epsilon==min|epsilon==max

* Aggregate elasticity and welfare
use base_import, clear
g welfare= alpha_kj_y/epsilon*(-log(w_kjj_y))
g var_welfare=(alpha_kj_y/(epsilon*epsilon)*(-log(w_kjj_y)))^2*varsigma
g lambda_ag=alpha_kj_y*w_kjj_y
bys iso3: egen _=sum(lambda_ag)
g inv_elast_ag=alpha_kj_y *log(w_kjj_y)/log(_)/epsilon
sort pays
collapse (sum) welfare var_welfare lambda_ag inv_elast_ag, by(pays)
g sd_welfare=sqrt(var_welfare)
g elast_ag=-log(lambda_ag)/welfare
g elast_ag_check=1/inv_elast_ag
g sd_elast_ag=sqrt((log(lambda_ag)/(welfare^2))^2*var_welfare)
order pays lambda_ag elast_ag sd_elast_ag welfare sd_welfare
br pays lambda_ag elast_ag sd_elast_ag welfare sd_welfar
export excel using "$tablepath\Table4_MasterAugust2016.xls", firstrow(variables) replace
sort pays
keep pays elast_ag
save temp_elast, replace

* Aggregate elasticity with an upper bar for sectoral elasticities at 80
use base_import, clear
replace sigma=80 if sigma>30.01
g welfare= alpha_kj_y/epsilon*(-log(w_kjj_y))
g var_welfare=(alpha_kj_y/(epsilon*epsilon)*(-log(w_kjj_y)))^2*varsigma
g lambda_ag=alpha_kj_y*w_kjj_y
bys iso3: egen _=sum(lambda_ag)
g inv_elast_ag=alpha_kj_y *log(w_kjj_y)/log(_)/epsilon
sort pays
collapse (sum) welfare var_welfare lambda_ag inv_elast_ag, by(pays)
g sd_welfare=sqrt(var_welfare)
g elast_ag=-log(lambda_ag)/welfare
br pays elast_ag 
export excel using "$tablepath\Table4Robust_MasterAugust2016.xls", firstrow(variables) replace

* International differences (Figure 3)
use base_import, clear
g _=alpha_kj_y*w_kjj_y
bys iso3: egen lambda_ag=sum(_)
drop _
g dlambda=log(w_kjj_y)/log(lambda_ag)
g share=alpha_kj_y*dlambda/epsilon
save temp, replace
keep if iso3=="USA"
rename share share_ref
rename alpha_kj_y alpha_ref
rename dlambda dlambda_ref
rename epsilon epsilon_ref
keep isic3 share_ref alpha_ref dlambda_ref epsilon_ref
sort isic3
save temp2, replace
use temp, clear
sort isic3
merge m:1 isic3 using temp2
drop _merge
bys iso3: egen __=sum(alpha_ref)
replace alpha_ref=alpha_ref/__
drop __
g B=-share_ref*(alpha_kj_y-alpha_ref)/alpha_ref
g L=-share_ref*(dlambda-dlambda_ref)/dlambda_ref
g E=share_ref*(epsilon-epsilon_ref)/epsilon_ref
sort pays iso3
collapse (sum) share_ref B L E, by(pays iso3)
replace B=B/share_ref
replace L=L/share_ref
replace E=E/share_ref
g overall=B+L+E
sort pays
merge pays using temp_elast
drop _merge
sum elast_ag if pays=="United States"
local ref=r(mean)
g depsilon=(elast_ag-`ref')/`ref'
foreach var in B L E{
	g `var'_rescaled=`var'/overall*depsilon
	
}
drop if pays=="United States"
br pays overall B L E depsilon B_rescaled L_rescaled E_rescaled
keep pays iso3 overall B L E depsilon B_rescaled L_rescaled E_rescaled
export excel using "$tablepath\Table5_MasterAugust2016.xls", firstrow(variables) replace
pwcorr overall depsilon, sig
gr tw (scatter overall depsilon , mlabel(iso3) m(smcircle)) (lfit overall depsilon ) , scheme(s1mono) legend(off) xtitle("Actual Elasticity Gap") ytitle("Approximated Elasticity Gap")
gr export "$graphpath\fig3_corr_actual_taylor.eps", replace
graph bar depsilon, over(pays , sort(depsilon) label(angle(45)))  bar(1,color(gs1)) ytitle("Elasticity gap with the US") scheme(s1mono) 
gr export "$graphpath\fig3_1.eps", replace
graph bar B_rescaled L_rescaled E_rescaled, over(pays , sort(depsilon) label(angle(45)))  stack  bar(1,color(gs5)) bar(2,color(gs2)) bar(3,color(gs10)) ytitle("Elasticity gap with the US") scheme(s1mono) legend(label(1 "Sectoral expenditures") label(2 "Sectoral openness") label(3 "Sectoral elasticities"))
gr export "$graphpath\fig3_2.eps", replace

erase temp.dta
erase temp2.dta
erase temp_elast.dta

